@@ -1,4 +1,5 @@
 import json
+import getpass
 
 from hvac.exceptions import InvalidRequest
 
@@ -22,6 +23,14 @@ class Admin(Vault):
         This will create new keys and will mean having to relaunch instances
         using vault creds.  Don't do this on redeploy!
         """
+        if self.config:
+            text = None
+            while text.lower() not in ["y", "n"]:
+                text = input("Server already exists in config.  Some values may be overwritten.  Continue? (y/n)")
+    
+            if text.lower() == "n":
+                print("Exiting...")
+                return
 
         if self.status_check() == 501:
             print("Status 501:  Initializing Vault...")
@@ -46,7 +55,7 @@ class Admin(Vault):
             print("Status 200:  Running Setup...")
             self.set_vault()
             self.__mount_ssh_backend()
-            self.write_signing_key()
+            self.__write_signing_key()
             self.__create_signing_role()
             self.__create_token_role()
 
@@ -63,17 +72,51 @@ class Admin(Vault):
 
     # --- SSH Keys ---
 
-    def write_signing_key(self, public_key=None, private_key=None):
+    def __write_signing_key(self, public_key=None, private_key=None):
         signing_key_address = "%s/config/ca" % MOUNT_POINT
+        try:
+            public_key = self.config["admin"]["publicSigningKey"]
+        except:
+            public_key = None
+        try:
+            private_key = self.config["admin"]["privateSigningKey"]
+        except:
+            private_key = None
+    
         try:
             if not public_key and not private_key:
-                self.vault.write(signing_key_address, generate_signing_key=True)
+                # self.vault.write(signing_key_address, generate_signing_key=True)
+                key_dict = self.__generate_signing_key()
+                public_key = key_dict["public_key"]
+                private_key = key_dict["private_key"]
             elif public_key and private_key:
-                self.vault.write(signing_key_address, public_key=public_key, private_key=private_key)
-            self.update_config("admin", {"publicSigningKey": self.get_public_signing_key()})
+                pass
+            else:
+                raise Exception("Public AND Private Keys must either both exist or neither.")
+            self.vault.write(signing_key_address, public_key=public_key, private_key=private_key)
+            self.update_config("admin", {
+                "publicSigningKey": public_key,
+                "privateSigningKey": private_key
+            })
         except InvalidRequest:
             print("Signing Key already written...")
 
+    def __generate_signing_key(self):
+        ssh_loc = "/Users/%s/.ssh" % getpass.getuser()
+        key_name = "vault-signing-%s" % self.server_name
+        self._command("echo -e 'y' | ssh-keygen -q -t rsa -b 4096 -f %s/%s -N ''" % (ssh_loc, key_name))
+        with open("%s/%s.pub" % (ssh_loc, key_name), 'r') as public_file:
+            public_key = public_file.read().replace('\n', '')
+            public_file.close()
+        with open("%s/%s.pub" % (ssh_loc, key_name), 'r') as private_file:
+            private_key = private_file.read().replace('\n', '')
+            private_file.close()
+        return {
+            "public_key": public_key,
+            "private_key": private_key
+        }
+        
+
     def get_public_signing_key(self):
         signing_key_address = "%s/config/ca" % MOUNT_POINT
         return self.vault.read(signing_key_address)['data']['public_key'].replace("\n", "")
