@@ -1,3 +1,5 @@
+import subprocess
+from os import environ
 from os.path import expanduser
 import json
 
@@ -93,4 +95,34 @@ class Vault(object):
         print('* ', text,  ' *')
         print('* ', ' ' * len(text),  ' *')
         print('*' * (len(text) + 6))
-        print("")
\ No newline at end of file
+        print("")
+
+    def _command(self, com_string, silent=True, env=environ.copy()):
+        process = subprocess.Popen(
+            com_string,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            shell=True,
+            env=env
+        )
+        output = process.communicate()
+        if not silent:
+            print("Running Command: %s" % com_string)
+            self.print_bytes(output[0])
+        try:
+            string_output = [x.decode("utf-8") for x in output]
+        except AttributeError:
+            string_output = output
+        if string_output[1] and "SNIMissingWarning" not in string_output[1] and "insecure" not in string_output[1].lower():
+            print("Errors:")
+            self.print_bytes(string_output[1])
+            raise Exception(string_output[1])
+        return output
+
+    @staticmethod
+    def _print_bytes(byte_string):
+        if isinstance(byte_string, bytes):
+            byte_string = byte_string.decode('utf-8')
+        string_list = byte_string.split("/n")
+        for string_item in string_list:
+            print(string_item)
\ No newline at end of file
